

"""\
This scripts helps with detecting the plumes as described in D4.
"""

from multiprocessing import Pool
import os
import pandas
import sys
import matplotlib.pyplot as plt
import numpy as np

import smartcarb as sc


#TRACER = 'CO2'
#ERROR = float(sys.argv[3])
#USE_EPF = True
#BG_TYPE = 'model'


def main(i):

    # create input filenames
    d = pandas.read_csv("data/pixels_in_Berlin_plumes_clouds.dat", sep='\t')
    fnames = d['filename'][d['XCO2'] > 0].values
    input_path = '/scratch/snx3000/gkuhl/smartcarb/level2/Sentinel_7_CO2/'
    input_fnames = [os.path.join(input_path, fn) for fn in fnames]

    # create output filenames
    if USE_EPF:
        suffix = '_%s_%02d-epf_bg-%s.dat' % (TRACER, 10*ERROR, BG_TYPE)
    else:
        suffix = '_%s_%02d_bg-%s.dat' % (TRACER, 10*ERROR, BG_TYPE)


    output_path = '/users/gkuhl/projects/smartcarb/plume_detection/results'
    output_fnames = [os.path.join(output_path, fn.replace('.nc', suffix))
            for fn in fnames]

    print(fnames[i])
    sc.plume.main(input_fnames[i], output_fnames[i], TRACER, ERROR, USE_EPF,
            cloud_thr=0.01, bg_type=BG_TYPE)



def quick_labels(fnames, output_path):
    for fn in fnames:
        print(os.path.basename(fn))
        res = sc.plume.show_all_ground_truths(fn, output_path=output_path)
        if res:
            plt.close()



if __name__ == '__main__':
    level2_path = '/project/smartcarb/data1/level2/Sentinel_7_CO2/'
    output_path = '/project/smartcarb/plume_detection'

    tracer = 'NO2'

    args = []

    for error_std in ['low', 'high']:
        for cloud_thr in [0.01, 0.30]:
            args.append([
                output_path, level2_path, tracer, error_std,
                'Berlin', 0.95, 5, cloud_thr
            ])

    with Pool(4) as pool:
        pool.starmap(sc.plume.main, args)





