#! /usr/bin/env python
# coding: utf-8

from datetime import datetime, timedelta

import smartcarb as sc



def main(time, origin, area):

    if origin == 'Berlin':
        tracer = 'XCO2_BV'
    else:
        tracer = 'XCO2_JV'

    slice_ = sc.io.get_slice(origin, area=area)

    # read signal and background
    filename = sc.io.create_filename(time, input_files='2D')
    signal, bg = sc.io.read_signal_and_background(filename, tracer, time=time,
            correct_berlin=True, slice_=slice_)

    # spatial binning to satellite resolution
    signal = sc.misc.spatial_binning(signal, n=2)
    bg = sc.misc.spatial_binning(bg, n=2)

    return bg.mean(), bg.std(), (bg+signal).mean(), (bg+signal).std()



if __name__ == '__main__':
    origin = 'Berlin'
    area = 100 # grid cells (i.e. 110 km)

    start = datetime(2015,1,1)
    end = datetime(2015,1,2)

    out_filename = 'test.dat'

    with open(out_filename, 'w') as out:
        out.write('UTC\tmean_bg\tstd_bg\tmean_tot\tstd_tot\n')

        for time in sc.misc.iter_times(start, end):
            out.write('%s\t' % str(time))
            out.write('\t'.join('%.2f' % v for v in main(time, origin, area)))
            out.write('\n')

